===================
OS-Faults |release|
===================

**OpenStack fault-injection library**

The library does destructive actions inside an OpenStack cloud. It provides
an abstraction layer over different types of cloud deployments. The actions
are implemented as drivers (e.g. DevStack driver, Fuel driver, Libvirt driver,
IPMI driver).

Contents
========

.. toctree::
   :maxdepth: 3

   quickstart/index
   cli
   drivers
   api
   contributing

Release Notes
=============

.. toctree::
   :maxdepth: 1

   history

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

